Changelog
---------
0.4.2
^^^^^
**release date:** 2021-03-20
* Fixes default configuration loading

0.4.1
^^^^^
**release date:** 2021-03-16
* Fixes missing default configuration files

0.4.0
^^^^^
**release date:** 2021-03-16
* Major refactoring
* Drop python 2 support
* Added support for languages and tags
* Added default rules

0.3.0
^^^^^
**release date:** 2021-03-02
* Python 3.x support

0.2.1
^^^^^
**release date:** 2016-02-28
* Adding guess encoding back without python-magic dependency.

0.2
^^^^^
**release date:** 2016-02-27
* Removing chardet and python-magic dependencies. Either encoding is specified or it should be guessed by pysrt

0.1
^^^^^
**release date:** 2015-10-16

* Initial release